@@ -36,14 +36,16 @@
 #include <gst/gst.h>
 #include <unique/unique.h>
 
-//#include <panel-applet.h>
-//#include <panel-applet-gconf.h>
+#include <config.h>
+
+#ifdef HAVE_APP_INDICATOR
+#include <libappindicator/app-indicator.h>
+#endif
 
 G_BEGIN_DECLS
 
 typedef struct _AlarmApplet AlarmApplet;
 
-const gchar *supported_sound_mime_types[];
 GHashTable *app_command_map;
 
 void alarm_applet_label_update (AlarmApplet *applet);
@@ -60,6 +62,7 @@ void alarm_applet_clear_alarms (AlarmApplet *applet);
 #define ALARM_NAME		 "Alarm Clock"
 #define ALARM_ICON 		 "alarm-clock"
 #define TIMER_ICON		 "alarm-timer"
+#define TRIGGERED_ICON	 "alarm-clock-triggered"
 #define ALARM_GCONF_DIR	 "/apps/alarm-clock"
 #define ALARM_STD_SNOOZE 9
 
@@ -76,8 +79,15 @@ struct _AlarmApplet {
     /* User Interface */
     GtkBuilder *ui;
 
+#ifdef HAVE_APP_INDICATOR
+    /* App Indicator */
+    AppIndicator *app_indicator;
+#else
 	/* Status Icon */
 	GtkStatusIcon *status_icon;
+#endif
+
+	/* Status menu */
     GtkWidget *status_menu;
     
 	/* Alarms */
@@ -116,9 +126,7 @@ struct _AlarmApplet {
     GtkAction *action_snooze_all;
     GtkToggleAction *action_toggle_list_win;
     GtkToggleAction *action_toggle_autostart;
-
-	/* GConf */
-	guint listeners [N_GCONF_PREFS];
+    GtkToggleAction *action_toggle_show_label;
 };
 
 void alarm_applet_sounds_load (AlarmApplet *applet);
