@@ -38,6 +38,16 @@ void
 autostart_monitor_changed(GFileMonitor *monitor, GFile *file,
 		GFile *other_file, GFileMonitorEvent event_type, gpointer user_data);
 
+void
+prefs_show_label_init (AlarmApplet *applet);
+
+void
+prefs_show_label_update (AlarmApplet *applet);
+
+void
+prefs_show_label_changed (GConfClient *client, guint cnxn_id,
+						  GConfEntry *entry, AlarmApplet *applet);
+
 /**
  * Initialize preferences dialog and friends
  */
@@ -48,6 +58,7 @@ prefs_init (AlarmApplet *applet)
 	applet->prefs_autostart_check = GTK_WIDGET (gtk_builder_get_object (applet->ui, "autostart-check"));
 
 	prefs_autostart_init (applet);
+	prefs_show_label_init (applet);
 }
 
 // Ordered list of autostart files we watch for
@@ -189,6 +200,7 @@ prefs_autostart_get_state ()
 		} else {
 			g_warning ("Preferences: Could not load autostart-file '%s': %s", filename, err->message);
 			g_error_free (err);
+			err = NULL;
 			g_free(filename);
 		}
 
@@ -200,6 +212,46 @@ prefs_autostart_get_state ()
 	return FALSE;
 }
 
+/**
+ * Create the ~/.config/autostart/alarm-clock-applet.desktop file
+ */
+static gboolean
+prefs_create_autostart_user_file()
+{
+	GFile *f;
+	GError *err = NULL;
+	gchar *filename;
+
+	// Create ~/.config/autostart if it doesn't exist
+	f = g_file_get_parent (autostart_user_file);
+	if (!g_file_query_exists (f, NULL)) {
+		g_debug ("Preferences: creating user autostart dir...");
+		if (!g_file_make_directory_with_parents (f, NULL, &err)) {
+			filename = g_file_get_path (f);
+			g_warning ("Preferences: Could not mkdir '%s': %s", filename, err->message);
+			g_free (filename);
+			g_object_unref (f);
+			return FALSE;
+		}
+	}
+
+	// Copy .desktop to autostart_user_file
+	filename = g_build_filename (ALARM_CLOCK_DATADIR, "applications", PACKAGE ".desktop", NULL);
+	f = g_file_new_for_path (filename);
+
+	if (!g_file_copy (f, autostart_user_file, G_FILE_COPY_NONE, NULL, NULL, NULL, &err)) {
+		g_warning ("Preferences: Could not copy '%s' to user config dir: %s", filename, err->message);
+		g_error_free (err);
+		err = NULL;
+		g_free (filename);
+		return FALSE;
+	}
+
+	g_free (filename);
+
+	return TRUE;
+}
+
 /**
  * Enable / disable autostart
  */
@@ -214,7 +266,6 @@ prefs_autostart_set_state (gboolean state)
 	}
 
 	GFile *file = prefs_autostart_get_current ();
-	GFile *f;
 	gchar *filename, *str;
 	gsize length;
 	GKeyFile *kf;
@@ -226,16 +277,8 @@ prefs_autostart_set_state (gboolean state)
 		g_debug ("Preferences: Autostart ENABLE!");
 
 		if (file != autostart_user_file) {
-			// Copy .desktop to autostart_user_file
-			filename = g_build_filename (ALARM_CLOCK_DATADIR, "applications", PACKAGE ".desktop", NULL);
-			f = g_file_new_for_path (filename);
-
-			if (!g_file_copy (f, autostart_user_file, G_FILE_COPY_NONE, NULL, NULL, NULL, &err)) {
-				g_warning ("Preferences: Could not copy '%s' to user config dir: %s", filename, err->message);
-				g_error_free (err);
-			}
-
-			g_free (filename);
+			if ( ! prefs_create_autostart_user_file() )
+			    return;
 		}
 
 		// Unset Hidden and X-GNOME-Autostart-enabled
@@ -268,6 +311,7 @@ prefs_autostart_set_state (gboolean state)
 		if (err) {
 			g_warning ("Preferences: Error when enabling autostart-file '%s': %s", filename, err->message);
 			g_error_free (err);
+			err = NULL;
 		}
 
 		g_free(filename);
@@ -278,16 +322,8 @@ prefs_autostart_set_state (gboolean state)
 
 		if (file) {
 			if (file != autostart_user_file) {
-				// Copy .desktop to autostart_user_file
-				filename = g_build_filename (ALARM_CLOCK_DATADIR, "applications", PACKAGE ".desktop", NULL);
-				f = g_file_new_for_path (filename);
-
-				if (!g_file_copy (f, autostart_user_file, G_FILE_COPY_NONE, NULL, NULL, NULL, &err)) {
-					g_warning ("Preferences: Could not copy '%s' to user config dir: %s", filename, err->message);
-					g_error_free (err);
-				}
-
-				g_free(filename);
+				if ( ! prefs_create_autostart_user_file() )
+				    return;
 			}
 
 			// Set Hidden=true
@@ -316,6 +352,7 @@ prefs_autostart_set_state (gboolean state)
 			if (err) {
 				g_warning ("Preferences: Error when disabling autostart-file '%s': %s", filename, err->message);
 				g_error_free (err);
+				err = NULL;
 			}
 
 		} else {
@@ -357,6 +394,102 @@ prefs_autostart_update (AlarmApplet *applet)
 	}
 }
 
+/**
+ * Initialize show_label preference
+ */
+void
+prefs_show_label_init (AlarmApplet *applet)
+{
+#ifdef HAVE_APP_INDICATOR
+	GConfClient *client = gconf_client_get_default ();
+
+	// Monitor gconf key
+	gconf_client_notify_add (
+			client, ALARM_GCONF_DIR "/show_label",
+			(GConfClientNotifyFunc) prefs_show_label_changed,
+			applet, NULL, NULL);
+
+	// Update state
+	prefs_show_label_update (applet);
+
+#else
+	// No AppIndicator support, disable option
+	GtkWidget *show_label_check = GTK_WIDGET (gtk_builder_get_object (applet->ui, "show-label-check"));
+	gtk_widget_set_sensitive (show_label_check, FALSE);
+	gtk_widget_set_tooltip_text (show_label_check, _("Requires application indicators"));
+
+	gtk_toggle_action_set_active (applet->action_toggle_show_label, FALSE);
+#endif
+}
+
+/**
+ * Get the current show_label state from GConf
+ */
+gboolean
+prefs_show_label_get (AlarmApplet *applet)
+{
+	GConfClient *client = gconf_client_get_default ();
+	GConfValue *value;
+	gboolean state;
+
+	// Get config value
+	value = gconf_client_get(client, ALARM_GCONF_DIR "/show_label", NULL);
+	if (value == NULL) {
+		g_warning ("Get %s failed", ALARM_GCONF_DIR "/show_label");
+		return gtk_toggle_action_get_active (applet->action_toggle_show_label);
+	}
+
+	state = gconf_value_get_bool (value);
+	gconf_value_free (value);
+
+	return state;
+}
+
+/**
+ * Set show_label state in GConf
+ */
+void
+prefs_show_label_set (AlarmApplet *applet, gboolean state)
+{
+	GConfClient *client = gconf_client_get_default ();
+	gboolean current_state = prefs_show_label_get (applet);
+
+	if (current_state == state) {
+		// No change
+		return;
+	}
+
+	// Set config value
+	gconf_client_set_bool (client, ALARM_GCONF_DIR "/show_label", state, NULL);
+}
+
+/**
+ * Update show_label state
+ */
+void
+prefs_show_label_update (AlarmApplet *applet)
+{
+	gboolean state = gtk_toggle_action_get_active (applet->action_toggle_show_label);
+	gboolean new_state = prefs_show_label_get (applet);
+
+	g_debug ("Preferences: Show_label update: new state: %d", new_state);
+
+	if (state != new_state) {
+		gtk_toggle_action_set_active (applet->action_toggle_show_label, new_state);
+	}
+}
+
+void
+prefs_show_label_changed (GConfClient  *client,
+					      guint         cnxn_id,
+					      GConfEntry   *entry,
+					      AlarmApplet  *applet)
+{
+	g_debug ("show_label_changed");
+
+	prefs_show_label_update (applet);
+}
+
 /**
  * Show preferences dialog
  */
