@@ -27,6 +27,8 @@
 #include <time.h>
 #include <glib.h>
 
+#include <config.h>
+
 /**
  * Calculates the alarm timestamp given hour, min and secs.
  */
@@ -48,4 +50,30 @@ command_run (const gchar *command);
 gboolean
 is_executable_valid (gchar *executable);
 
+/* Get full path of a data file */
+char *
+alarm_applet_get_data_path (const char *name);
+
+guint
+block_signal_handlers_by_name (gpointer instance, const gchar *signal_name);
+
+guint
+unblock_signal_handlers_by_name (gpointer instance, const gchar *signal_name);
+
+guint
+block_list (GList *instances, gpointer func);
+
+guint
+unblock_list (GList *instances, gpointer func);
+
+#define BLOCK(instance, func)   \
+    g_signal_handlers_block_matched ((instance),            \
+                                     G_SIGNAL_MATCH_FUNC,   \
+                                     0, 0, NULL, (func), NULL)
+
+#define UNBLOCK(instance, func)   \
+    g_signal_handlers_unblock_matched ((instance),            \
+                                       G_SIGNAL_MATCH_FUNC,   \
+                                       0, 0, NULL, (func), NULL)
+
 #endif /*UTIL_H_*/
